==> liquibase-mongodb-4.3.3-sources.jar: liquibase/ext/mongodb/change/InsertOneChange.java <==
package liquibase.ext.mongodb.change;

/*-
 * #%L
 * Liquibase MongoDB Extension
 * %%
 * Copyright (C) 2019 Mastercard
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

import liquibase.change.ChangeMetaData;
import liquibase.change.DatabaseChange;
import liquibase.database.Database;
import liquibase.ext.mongodb.statement.InsertOneStatement;
import liquibase.statement.SqlStatement;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@DatabaseChange(name = "insertOne",
        description = "Insert a Single Document " +
                "https://docs.mongodb.com/manual/tutorial/insert-documents/#insert-a-single-document",
        priority = ChangeMetaData.PRIORITY_DEFAULT, appliesTo = "collection")
@NoArgsConstructor
@Getter
@Setter
public class InsertOneChange extends AbstractMongoChange {

    private String collectionName;
    private String document;
    private String options;

    @Override
    public String getConfirmationMessage() {
        return "Document inserted into collection " + getCollectionName();
    }

    @Override
    public SqlStatement[] generateStatements(final Database database) {
        return new SqlStatement[]{
                new InsertOneStatement(collectionName, document, options)
        };
    }
}

==> liquibase-mongodb-4.32.0-sources.jar: liquibase/ext/mongodb/change/InsertOneChange.java <==
package liquibase.ext.mongodb.change;

/*-
 * #%L
 * Liquibase MongoDB Extension
 * %%
 * Copyright (C) 2019 Mastercard
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

import liquibase.change.ChangeMetaData;
import liquibase.change.CheckSum;
import liquibase.change.DatabaseChange;
import liquibase.database.Database;
import liquibase.ext.mongodb.statement.InsertOneStatement;
import liquibase.statement.SqlStatement;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@DatabaseChange(name = "insertOne",
        description = "Insert a Single Document " +
                "https://docs.mongodb.com/manual/tutorial/insert-documents/#insert-a-single-document",
        priority = ChangeMetaData.PRIORITY_DEFAULT, appliesTo = "collection")
@NoArgsConstructor
@Getter
@Setter
public class InsertOneChange extends AbstractMongoChange {

    private String collectionName;
    private String document;
    private String options;

    @Override
    public String getConfirmationMessage() {
        return "Document inserted into collection " + getCollectionName();
    }

    @Override
    public SqlStatement[] generateStatements(final Database database) {
        return new SqlStatement[]{
                new InsertOneStatement(collectionName, document, options)
        };
    }

    @Override
    public CheckSum generateCheckSum() {
        return super.generateCheckSum(collectionName, document, options);
    }
}
